<?php
// $Id: media_wistia.theme.inc,v 1.1 2011/02/06 00:14:35 evandonovan Exp $

/**
 * @file
 * media_wistia/themes/media_wistia.theme.inc
 * Theme functions for Media: Wistia.
 */

/**
 * Preprocess function for Wistia player:
 * Gets the player options, and adds them to the template.
 * @TODO: - add the playbutton, controls_visible, and end_video_behavior parameters
 *        - add caching of the $embed_code.
 */
function template_preprocess_media_wistia(&$variables) {
  _media_wistia_options($variables);
  // Sets the width and height: use default width and height if none are set by the calling function.
  $variables['width'] = isset($variables['width']) ? $variables['width'] : media_wistia_variable_get('default_width');
  $variables['height'] = isset($variables['height']) ? $variables['height'] : media_wistia_variable_get('default_height');

  // Requests the embed code from Wistia based on the Media ID (video_code)
  // @TODO: move this into a helper function
  if ($variables['video_code']) {
    $scheme =  'https';
    $user = 'api';
    $pass = media_wistia_variable_get('api_key');
    // Sets host (api.wistia.com)
    $host = MEDIA_WISTIA_API_HOST;
    // @TODO: make the v1 a constant, rather than hard-coded
    $path = '/v1/medias/' . $variables['video_code'] . '/embed';
    if (isset($variables['width'])) {
      $query['width'] = 'embed_code_options[width]=' . $variables['width'];
    }
    if (isset($variables['height'])) {
      $query['height'] = 'embed_code_options[height]=' . $variables['height'];
    }
    if (isset($variables['autoplay']) && $variables['autoplay'] == TRUE) {
      $query['autoplay'] = 'embed_code_options[autoplay]=1';
    }
    // Implodes the query string options with an '&'
    $query = implode($query, '&');
    // Builds the URL for drupal_http_request to use to get the embed code
    // @TODO: use ternary operator to handle case of missing query string
    /* Expected format: https://api:<api-key>@api.wistia.com/v1/medias/<media-id>/embed?
                        embed_code_options[width]=<width>&embed_code_options[height]=<height> */
    $embed_url = $scheme . '://' . $user . ':' . $pass . '@' . $host . $path . '?' . $query;
    $result = drupal_http_request($embed_url);
    // @TODO: Add regex to validate as a correct embed code
    if (isset($result) && in_array($result->code, array('200', '302', '307')) && $result->data != '') {
      $variables['embed_code'] = $result->data;
    }
  }
}

/**
 * Helper function for template_preprocess_media_wistia:
 * Turns the $variables['options'] array passed into the theming function
 * into a set of variables directly in preprocess.
 */
function _media_wistia_options(&$variables) {
  foreach ($variables['options'] as $key => $value) {
    $variables[$key] = $value;
  }
  unset($variables['options']);
}